/*
 *  Copyright (C) 2004 OntoText Lab, Sirma AI OOD
 *
 *  Address:
 *  Europe            135 Tsarigradsko Shose, Sofia 1784, Bulgaria
 *                    (IT Center Office Express, 3rd floor)
 *
 *  North America     438 Isabey Str, Suite 103, Montreal, Canada H4T 1V3
 *
 *  Phone: (+359 2) 9768 310
 *  Fax: (+359 2) 9768 311
 *
 *
 *  E-mail:                          info@ontotext.com
 *  Web:                             http://www.ontotext.com
 *  Sirma Group International Corp.  http://www.sirma.com
 *  Sirma AI Ltd.                    http://www.sirma.bg
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.openrdf.util.rmirouting;

/**
 * RoutingAction instances are used to perform some custom setup/cleanup actions
 * during a remote method invocation. They are used in conjunction with the provided
 * 'session' cookie in an attempt to provide some aid with the proper server context
 * alignment. If such an alignment is not neccessary, it is better to not set any
 * cookie and custom prolog/epilog actions into <code>ChanelIfaceImpl</code>.
 *
 * @see org.openrdf.util.rmirouting.ChannelIfaceImpl#setPrologAction(RoutingAction) setPrologAction
 * @see org.openrdf.util.rmirouting.ChannelIfaceImpl#setCurrentCookie(Object) setCurrentCookie
 */

public interface RoutingAction {

  /**
   * Here the implementor should take the necessary actions to align the server context
   * using the provided cokkie into that method
   * @param cookie that will be used to align the server's running coontext
   */
  public void doRoutingAction(Object cookie);
}
